<?php

/**
 * @file
 * Provides theme overrides and implementations for the System module.
 */

/**
 * Preprocesses variables for html.tpl.php.
 */
function tweme_preprocess_html(&$vars) {
  if ($max_width = theme_get_setting('max_width')) {
    _tweme_add_asset(
      'css',
      '@media (min-width: 1200px) {
        .container {
          width: ' . ($max_width + 30) . 'px;
        }
      }',
      array(
        'type' => 'inline',
        'group' => CSS_THEME,
        'browsers' => 'modern',
        'media' => 'screen',
      )
    );
  }
}

/**
 * Preprocesses variables for page.tpl.php.
 */
function tweme_preprocess_page(&$vars) {

  // Prepare navbar menu:
  if ($menu = variable_get('menu_main_links_source')) {
    $vars['navbar_menu_tree'] = menu_tree($menu);
    unset($vars['navbar_menu_tree']['#theme_wrappers']);      
  }

  // Prepare navbar search form:
  $vars['navbar_search_form'] = FALSE;
  if (module_exists('search')) {
    $form = drupal_get_form('search_form');
    unset($form['basic']['keys']['#theme_wrappers']);
    $form['#attributes']['class'][] = 'navbar-form';
    $form['#attributes']['class'][] = 'pull-right';
    $form['#theme_wrappers'][] = 'pure_form_wrapper';
    $vars['navbar_search_form'] = $form;
  }
}

/**
 * Processes variables for page.tpl.php.
 */
function tweme_process_page(&$vars) {
  $page = $vars['page'];
  
  // Provide additional variables for template:
  $vars['navbar_brand'] = theme('navbar_brand', array(
    'name' => $vars['site_name'],
    'href' => $vars['front_page'],
    'logo' => $vars['logo'],
  ));
  $vars['navbar_menu'] = NULL;
  if (isset($vars['navbar_menu_tree'])) {
    $vars['navbar_menu'] = '<ul class="nav navbar-nav">' . drupal_render($vars['navbar_menu_tree']) . '</ul>';
  }
  $vars['navbar_search'] = drupal_render($vars['navbar_search_form']);
  $vars['navbar_toggler'] = theme('navbar_toggler');
  $vars['headline'] = theme('page_headline', $vars);
  $vars['controls'] = theme('page_controls', $vars);
  $vars['copyright'] = theme('copyright', array('name' => $vars['site_name']));
}

/**
 * Overrides theme_menu_local_tasks().
 */
function tweme_menu_local_tasks($vars) {
  $out = '';
  if (!empty($vars['primary'])) {
    $vars['primary']['#prefix'] = '<ul class="nav nav-' . theme_get_setting('primary_tasks_style') . '">';
    $vars['primary']['#suffix'] = '</ul>';
    $out .= drupal_render($vars['primary']);
  }
  if (!empty($vars['secondary'])) {
    $vars['secondary']['#prefix'] = '<ul class="nav nav-' . theme_get_setting('secondary_tasks_style') . '">';
    $vars['secondary']['#suffix'] = '</ul>';
    $out .= drupal_render($vars['secondary']);
  }
  return $out;
}

/**
 * Overrides theme_item_list().
 */
function tweme_item_list($vars) {
  if (isset($vars['attributes']['class']) && in_array('pager', $vars['attributes']['class'])) {
    $vars['attributes']['class'] = array('pagination');
    foreach ($vars['items'] as $i => &$item) {
      if (in_array('pager-current', $item['class'])) {
        $item['class'] = array('active');
        $item['data'] = '<a href="#">' . $item['data'] . '</a>';
      }
      elseif (in_array('pager-ellipsis', $item['class'])) {
        $item['class'] = array('disabled');
        $item['data'] = '<a href="#">' . $item['data'] . '</a>';
      }
    }
  }
  return theme_item_list($vars);
}

/**
 * Preprocesses variables for theme_button().
 */
function tweme_preprocess_button($vars) {
  $vars['element']['#attributes']['class'][] = 'btn';
  $is_primary = (isset($vars['element']['#parents'][0]) && $vars['element']['#parents'][0] == 'submit');
  $vars['element']['#attributes']['class'][] = ($is_primary ? 'btn-primary' : 'btn-default');
}
